@@ -1,40 +1,5 @@
 var NAVTREEINDEX20 =
 {
-"structpw__resource__events.html":[10,5,14,1],
-"structpw__resource__events.html#a0472df3f84251f7c7f5a36692bd0ac6e":[10,5,14,1,1],
-"structpw__resource__events.html#a0a276ed65fe8f88887e9fbd0d08df018":[10,5,14,1,2],
-"structpw__resource__events.html#a41e29d4a60ff80ff183c2cb56060f7e9":[10,5,14,1,0],
-"structpw__resource__events.html#af8ab8db63d0b4e3a332ff552e416e5a2":[10,5,14,1,3],
-"structpw__session.html":[10,7,4,24],
-"structpw__session__events.html":[10,7,4,10],
-"structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c":[10,7,4,10,1],
-"structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7":[10,7,4,10,2],
-"structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7":[10,7,4,10,0],
-"structpw__session__info.html":[10,7,4,18],
-"structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
-"structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
-"structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
-"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
-"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
-"structpw__session__methods.html":[10,7,4,11],
-"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
-"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[10,7,4,11,4],
-"structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0":[10,7,4,11,2],
-"structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09":[10,7,4,11,3],
-"structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf":[10,7,4,11,1],
-"structpw__stream.html":[10,0,5],
-"structpw__stream__control.html":[10,0,2],
-"structpw__stream__control.html#a40b47654929367a6a4f1b83b0b68bfb1":[10,0,2,3],
-"structpw__stream__control.html#a4167f3df47a2d2deff793d3f1f6d31d2":[10,0,2,0],
-"structpw__stream__control.html#a4541b454ba4caaf23f4e772f431294c1":[10,0,2,1],
-"structpw__stream__control.html#a4ffcfbdb7762b0650a28f10eb8c10046":[10,0,2,6],
-"structpw__stream__control.html#a61f6208ade53511ac42e01185f270f62":[10,0,2,2],
-"structpw__stream__control.html#a925311b76a91a9034391da7343865091":[10,0,2,5],
-"structpw__stream__control.html#addabfd3b77bb0cb58bb65b779ab1b3d5":[10,0,2,4],
-"structpw__stream__events.html":[10,0,4],
-"structpw__stream__events.html#a0cdc45fef5f2458a0fd11a6e9ef1f6fb":[10,0,4,7],
-"structpw__stream__events.html#a12fa5918ff2c41cc41d5bf8ae36b3ca3":[10,0,4,3],
-"structpw__stream__events.html#a1de8432b45484bc0e060162b78720c02":[10,0,4,11],
 "structpw__stream__events.html#a4d1ed03aa78fb2c8324ae13bc45731e3":[10,0,4,5],
 "structpw__stream__events.html#a512bd219ce44ba1a688d600773efe84b":[10,0,4,8],
 "structpw__stream__events.html#a66e43e35eb2be261520cda8a4e24098c":[10,0,4,10],
@@ -68,53 +33,103 @@ var NAVTREEINDEX20 =
 "structpwtest__spa__plugin.html#aef8a87ec887314f7a70366be56138406":[10,2,1,4],
 "structpwtest__suite.html":[10,2,3],
 "structpwtest__test.html":[10,2,4],
-"structspa__audio__aec.html":[11,0,137],
-"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[11,0,137,1],
-"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[11,0,137,2],
-"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[11,0,137,0],
-"structspa__audio__aec__events.html":[11,0,138],
-"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[11,0,138,1],
-"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[11,0,138,0],
-"structspa__audio__aec__info.html":[11,0,139],
-"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,139,0],
-"structspa__audio__aec__methods.html":[11,0,140],
-"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,140,1],
-"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,140,4],
-"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,140,6],
-"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,140,5],
-"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,140,3],
-"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,140,0],
-"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,140,2],
-"structspa__audio__info.html":[10,8,7,20],
-"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,20,5],
-"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,20,3],
-"structspa__audio__info.html#a1c0fd971fb059d844722a21feeb3de59":[10,8,7,20,6],
-"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,20,1],
-"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,20,2],
-"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,20,0],
-"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[10,8,7,20,4],
-"structspa__audio__info__dsd.html":[10,8,7,19],
-"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,19,5],
-"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,19,4],
-"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[10,8,7,19,0],
-"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,19,3],
-"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,19,2],
-"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,19,1],
-"structspa__audio__info__dsp.html":[10,8,7,24],
-"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[10,8,7,24,0],
-"structspa__audio__info__iec958.html":[10,8,7,21],
-"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,21,1],
-"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,21,0],
-"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,21,2],
-"structspa__audio__info__raw.html":[10,8,7,23],
-"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,23,0],
-"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,23,3],
-"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,23,1],
-"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,23,4],
-"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,23,2],
-"structspa__audio__layout__info.html":[10,8,7,22],
-"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,22,1],
-"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,22,0],
+"structspa__audio__aec.html":[11,0,138],
+"structspa__audio__aec.html#a09e1e6ddb6cba06861e418fad8eb2442":[11,0,138,1],
+"structspa__audio__aec.html#a2c343b0ced8bc8a9d22c441558c1cc9f":[11,0,138,2],
+"structspa__audio__aec.html#a472c09f9a147170d0892a650b60c9b5d":[11,0,138,0],
+"structspa__audio__aec__events.html":[11,0,139],
+"structspa__audio__aec__events.html#a355f3bedb9b4094912577187225797d9":[11,0,139,1],
+"structspa__audio__aec__events.html#ab137f922d3a547caf388c5c11be2e5ce":[11,0,139,0],
+"structspa__audio__aec__info.html":[11,0,140],
+"structspa__audio__aec__info.html#a88dbf8b905a3f808af985764cb21fd7c":[11,0,140,0],
+"structspa__audio__aec__methods.html":[11,0,141],
+"structspa__audio__aec__methods.html#a028adaf84c4fb5c19e416c53874ad57f":[11,0,141,8],
+"structspa__audio__aec__methods.html#a0e357608392e4e4cf8224a523882a80c":[11,0,141,1],
+"structspa__audio__aec__methods.html#a0ea3331fe5e9ceed6a0969c4f2aaa4c3":[11,0,141,4],
+"structspa__audio__aec__methods.html#a1d1c3a7ec1bd783ddb3cea31bc421cb1":[11,0,141,6],
+"structspa__audio__aec__methods.html#a5b18f9a4430576c06bf7067a61a97854":[11,0,141,5],
+"structspa__audio__aec__methods.html#a73977fea4b6c069260af4f16b08ceee0":[11,0,141,10],
+"structspa__audio__aec__methods.html#aa75447be29ace8e48fefb525ed44bcd8":[11,0,141,7],
+"structspa__audio__aec__methods.html#aadf3db584c3062de5a2af134e6d7014d":[11,0,141,3],
+"structspa__audio__aec__methods.html#af6f30eee3a6af553b3e6ef83f850a691":[11,0,141,0],
+"structspa__audio__aec__methods.html#af75957ae10a92bb2253df67aa6eca97f":[11,0,141,9],
+"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503":[11,0,141,2],
+"structspa__audio__info.html":[10,8,7,34],
+"structspa__audio__info.html#a07b9f000b469ff8389b93290a5a06b2b":[10,8,7,34,5],
+"structspa__audio__info.html#a0c0ba9b2cb3625fdbfa3a5f1a00639d3":[10,8,7,34,16],
+"structspa__audio__info.html#a1042e506082d62d0c5371c3d9d349a9a":[10,8,7,34,8],
+"structspa__audio__info.html#a1831d447b0446ff947e879f2de34d410":[10,8,7,34,3],
+"structspa__audio__info.html#a41f273519b13112d24c1a7066755e3d8":[10,8,7,34,11],
+"structspa__audio__info.html#a5470ad19233fb9e3136d500296a74d75":[10,8,7,34,1],
+"structspa__audio__info.html#a5d87c4474c9eb1a61153dd460599591b":[10,8,7,34,6],
+"structspa__audio__info.html#a635122b47bf1de20dd009ecca6cdb7d3":[10,8,7,34,10],
+"structspa__audio__info.html#a755a925f66d28b0e9912482e97375b7a":[10,8,7,34,2],
+"structspa__audio__info.html#a880d36c25907b88e7ca3dc34d200c343":[10,8,7,34,15],
+"structspa__audio__info.html#a9128e8bd148abec71d6261dc5af9a7d9":[10,8,7,34,14],
+"structspa__audio__info.html#a9782c7a01047c3a1058fd8dd40c5f52b":[10,8,7,34,7],
+"structspa__audio__info.html#a99282e01caf417fe4ee63458ccdb6b30":[10,8,7,34,0],
+"structspa__audio__info.html#aa02a98d24c25c529d6b387ed1eb7074e":[10,8,7,34,4],
+"structspa__audio__info.html#ab9bbd067632a6e02f042dacff838c89b":[10,8,7,34,9],
+"structspa__audio__info.html#add88e2561d596e2d9d79bf772c7c6972":[10,8,7,34,12],
+"structspa__audio__info.html#ae9fd0fa99badc8be9ce0e59bb75f31f9":[10,8,7,34,13],
+"structspa__audio__info__aac.html":[11,0,143],
+"structspa__audio__info__aac.html#a16974760cfa2cbe91398d01fb7f4b947":[11,0,143,1],
+"structspa__audio__info__aac.html#a3b08334e341344e0035a7ee94a5c87a2":[11,0,143,2],
+"structspa__audio__info__aac.html#ab29a8d8e1cba013ab5008404ba2836ea":[11,0,143,0],
+"structspa__audio__info__aac.html#ad93ec0c832f6ed449d9e073068e221d1":[11,0,143,3],
+"structspa__audio__info__alac.html":[11,0,144],
+"structspa__audio__info__alac.html#a93d94a062b877bdb495bd1b07364f05d":[11,0,144,0],
+"structspa__audio__info__alac.html#afd38ff2d76cd8078e80f8955dc23da19":[11,0,144,1],
+"structspa__audio__info__amr.html":[11,0,145],
+"structspa__audio__info__amr.html#a1b1d2870fa166b3de6bf2f5b1b45a05d":[11,0,145,1],
+"structspa__audio__info__amr.html#a42ebba3d8e2cdd474ef49fb4c4c6b0f4":[11,0,145,2],
+"structspa__audio__info__amr.html#ac715c7089e6ff2b562a3762bd46136cb":[11,0,145,0],
+"structspa__audio__info__ape.html":[11,0,146],
+"structspa__audio__info__ape.html#a72509a439dfbe203c6c3653bed2153ed":[11,0,146,0],
+"structspa__audio__info__ape.html#a82e8f9bb5e9bd7bd014a92709a06b9f9":[11,0,146,1],
+"structspa__audio__info__dsd.html":[10,8,7,33],
+"structspa__audio__info__dsd.html#a4f11fce0402edcbe61f0b35f27396ac9":[10,8,7,33,5],
+"structspa__audio__info__dsd.html#a563add98a612fe3617a58e2cb1a703bc":[10,8,7,33,4],
+"structspa__audio__info__dsd.html#a698a141255b6d57f04d56de0fa52d170":[10,8,7,33,0],
+"structspa__audio__info__dsd.html#a72a8060d8747abb6e380e0dc0261157e":[10,8,7,33,3],
+"structspa__audio__info__dsd.html#a902dd094aab140dc3500a3a36ef967da":[10,8,7,33,2],
+"structspa__audio__info__dsd.html#a9f7ed724310d9b5a2c95607399fe3a34":[10,8,7,33,1],
+"structspa__audio__info__dsp.html":[11,0,148],
+"structspa__audio__info__dsp.html#ab59df8be3387df377c8b698346aa234f":[11,0,148,0],
+"structspa__audio__info__flac.html":[11,0,149],
+"structspa__audio__info__flac.html#a3351a0cbf04538db70fac13cd630e79e":[11,0,149,1],
+"structspa__audio__info__flac.html#a9be31890542f5995b7bbe493cd29f688":[11,0,149,0],
+"structspa__audio__info__iec958.html":[10,8,7,35],
+"structspa__audio__info__iec958.html#ab4797480f2e4e7f25d19a0a42c748eac":[10,8,7,35,1],
+"structspa__audio__info__iec958.html#adc76e7bde0fc3d66ffa5a8442c3b1409":[10,8,7,35,0],
+"structspa__audio__info__iec958.html#af028b6675757cd4504ad1b11a2e746c7":[10,8,7,35,2],
+"structspa__audio__info__mp3.html":[11,0,151],
+"structspa__audio__info__mp3.html#a2066d86c3d391a097c57441f8c391234":[11,0,151,0],
+"structspa__audio__info__mp3.html#a9eab81f1ef553124803e7563d7ffce93":[11,0,151,1],
+"structspa__audio__info__opus.html":[11,0,152],
+"structspa__audio__info__opus.html#ab354cfeab8ed9e4561332f86f77f5397":[11,0,152,1],
+"structspa__audio__info__opus.html#abf65d8f7d0877d50068bb68cff1f3e44":[11,0,152,0],
+"structspa__audio__info__ra.html":[11,0,153],
+"structspa__audio__info__ra.html#a281cd0f54656e1ccfda03854e5d36ce2":[11,0,153,1],
+"structspa__audio__info__ra.html#aa5374f33cf4a773ca3bb779d3e199fc9":[11,0,153,0],
+"structspa__audio__info__raw.html":[10,8,7,37],
+"structspa__audio__info__raw.html#a542692f9d3518632e37ea575d13ca149":[10,8,7,37,0],
+"structspa__audio__info__raw.html#a5a7e0c093143ba0820e936ece11f0952":[10,8,7,37,3],
+"structspa__audio__info__raw.html#a696f18b889bb8a5496e16dd48f7d8e01":[10,8,7,37,1],
+"structspa__audio__info__raw.html#ac21ae45356ef4e1dbfde141937fde9c5":[10,8,7,37,4],
+"structspa__audio__info__raw.html#ae7e501bbfbef2cd75f3ae0f13719652c":[10,8,7,37,2],
+"structspa__audio__info__vorbis.html":[11,0,155],
+"structspa__audio__info__vorbis.html#a7614ad24e4491223d0d44c1931c3089b":[11,0,155,0],
+"structspa__audio__info__vorbis.html#afec5882d3af8e9d177b4b0771c176046":[11,0,155,1],
+"structspa__audio__info__wma.html":[11,0,156],
+"structspa__audio__info__wma.html#a08102a7049195a3a9f5b734a6b8f7be5":[11,0,156,1],
+"structspa__audio__info__wma.html#a0bf6e6bad02abf194f2d65b5b458e7ba":[11,0,156,4],
+"structspa__audio__info__wma.html#a328501d7905f732937932d3731916a55":[11,0,156,3],
+"structspa__audio__info__wma.html#a46f090f295f02f54aaa427abb93d44e2":[11,0,156,2],
+"structspa__audio__info__wma.html#ad572e9079c943a87b18d96060ced5af4":[11,0,156,0],
+"structspa__audio__layout__info.html":[10,8,7,36],
+"structspa__audio__layout__info.html#a939d325d78f6c2cb4492fda99fe3efd0":[10,8,7,36,1],
+"structspa__audio__layout__info.html#abd815a9154f329d6a02f84f222bca93a":[10,8,7,36,0],
 "structspa__buffer.html":[10,8,1,7],
 "structspa__buffer.html#a026a97e0dfd3a606480f436fa61e204b":[10,8,1,7,0],
 "structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[10,8,1,7,2],
@@ -178,6 +193,16 @@ var NAVTREEINDEX20 =
 "structspa__dbus__methods.html":[10,8,9,1,4],
 "structspa__dbus__methods.html#a1e518bcb13046ec6b46a927024b6cc28":[10,8,9,1,4,1],
 "structspa__dbus__methods.html#a6e090fa6083fa425460f631ea48c3434":[10,8,9,1,4,0],
+"structspa__debug__context.html":[10,8,3,9],
+"structspa__debug__context.html#a5d5a27395a63043da36af7b1289cc711":[10,8,3,9,0],
+"structspa__debug__log__ctx.html":[10,8,3,10],
+"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724":[10,8,3,10,6],
+"structspa__debug__log__ctx.html#a49ae612d5a9f8abff00d338e0f42f338":[10,8,3,10,5],
+"structspa__debug__log__ctx.html#a7834e2a074032895d9760015da193685":[10,8,3,10,1],
+"structspa__debug__log__ctx.html#a7ef044cf8f043c056c0f09e7dc52772f":[10,8,3,10,2],
+"structspa__debug__log__ctx.html#a89c265ff2c1860bc78cb3a71e016c44a":[10,8,3,10,0],
+"structspa__debug__log__ctx.html#abcfc47fb7d6acf39603b9a1547edd1e7":[10,8,3,10,4],
+"structspa__debug__log__ctx.html#afcdc7fd8504c905b64485893b6816ee2":[10,8,3,10,3],
 "structspa__device.html":[10,8,4,3],
 "structspa__device.html#a00d8f19734c35525e99ecaab33113d3f":[10,8,4,3,0],
 "structspa__device__events.html":[10,8,4,7],
@@ -211,43 +236,18 @@ var NAVTREEINDEX20 =
 "structspa__dict__item.html":[10,8,8,2,1],
 "structspa__dict__item.html#a16dc8153e2ea77c9c82380456734478a":[10,8,8,2,1,0],
 "structspa__dict__item.html#af08479e3ff870039be002b436a02457d":[10,8,8,2,1,1],
-"structspa__dll.html":[11,0,167],
-"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,167,2],
-"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,167,1],
-"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,167,6],
-"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,167,3],
-"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,167,4],
-"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,167,0],
-"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,167,5],
+"structspa__dll.html":[11,0,180],
+"structspa__dll.html#a6e71bca8352ac6213b6d26c22732c9a1":[11,0,180,2],
+"structspa__dll.html#a7b2d7a0adb6cdc3680db685fef886d78":[11,0,180,1],
+"structspa__dll.html#a90a86177cee5a8c972d4a2825244d3de":[11,0,180,6],
+"structspa__dll.html#aa109171408f82fa3f287b70e2396ba42":[11,0,180,3],
+"structspa__dll.html#aa99d781b6e4c1133db7bef843fc4a21a":[11,0,180,4],
+"structspa__dll.html#ac3de731c327763f69c44e98224ee1068":[11,0,180,0],
+"structspa__dll.html#ae1e3a33d3f38548692173d283b613574":[11,0,180,5],
 "structspa__event.html":[10,8,0,15],
 "structspa__event.html#a1cfdf789b23f6f0ba623f3fc973951bb":[10,8,0,15,1],
 "structspa__event.html#a2411141eed88d3587687a8d86c99d488":[10,8,0,15,0],
 "structspa__event__body.html":[10,8,0,14],
 "structspa__event__body.html#aa484bc2cadd16a104476183666de3819":[10,8,0,14,0],
-"structspa__fraction.html":[10,8,8,1,4],
-"structspa__fraction.html#a55246db96d647cd96be18983d59feb56":[10,8,8,1,4,0],
-"structspa__fraction.html#af099fb3a18c93ddac10239564da9de0c":[10,8,8,1,4,1],
-"structspa__graph.html":[10,8,5,3],
-"structspa__graph.html#a850c90822a1b32d7cd67ec5c76eda2fa":[10,8,5,3,0],
-"structspa__graph.html#a90439529765f13aadc6f1d7727244a1c":[10,8,5,3,3],
-"structspa__graph.html#a9bcd83554b53da4a139ed6a9be38bb1c":[10,8,5,3,1],
-"structspa__graph.html#aacd6dde80b95c6415d300f419ea6f144":[10,8,5,3,2],
-"structspa__graph__link.html":[10,8,5,2],
-"structspa__graph__link.html#a15313bfb8509b74448784ebf30f191c6":[10,8,5,2,1],
-"structspa__graph__link.html#ab1f910424f6a5ea5a34b52695536f53d":[10,8,5,2,0],
-"structspa__graph__link.html#ab7c807f9aaa9242cf8573b13212de674":[10,8,5,2,2],
-"structspa__graph__link.html#abf9a5059f5b888cf3a331832830f7373":[10,8,5,2,3],
-"structspa__graph__node.html":[10,8,5,5],
-"structspa__graph__node.html#a23c316f71a255a568e96092e72c40cae":[10,8,5,5,4],
-"structspa__graph__node.html#a6215edd0d426cfc8e697d648c09a4f57":[10,8,5,5,0],
-"structspa__graph__node.html#a6664b3c60baddc151a340bf2ebb3a5a2":[10,8,5,5,8],
-"structspa__graph__node.html#a7a4bea046f4d6a88d97e12a5297ed740":[10,8,5,5,1],
-"structspa__graph__node.html#ab16592a35d02f827271786b49110341c":[10,8,5,5,7],
-"structspa__graph__node.html#acbee04440eefb9b0a77f69ff1876dbc0":[10,8,5,5,6],
-"structspa__graph__node.html#acfb4e7658140701927336dee05ed1948":[10,8,5,5,3],
-"structspa__graph__node.html#ada29bc9109cd890c74cfba630989b76c":[10,8,5,5,5],
-"structspa__graph__node.html#aec1169015c1d7a4aaea10d5f4946f7d4":[10,8,5,5,2],
-"structspa__graph__node.html#af4ae9586aa3d544a48414987f1839a67":[10,8,5,5,9],
-"structspa__graph__node__callbacks.html":[10,8,5,4],
-"structspa__graph__node__callbacks.html#a9c7b2744d4983173d88469654e626375":[10,8,5,4,1]
+"structspa__fraction.html":[10,8,8,1,4]
 };
